#
# spec file for package givaro
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           givaro
%define lname   libgivaro9
Version:        4.2.0
Release:        3.2
Summary:        C++ library for arithmetic and algebraic computations
License:        CECILL-B
Group:          Productivity/Scientific/Math
URL:            https://casys.gricad-pages.univ-grenoble-alpes.fr/givaro/

#Git-Clone:	https://github.com/linbox-team/givaro
Source:         https://github.com/linbox-team/givaro/releases/download/v%version/%name-%version.tar.gz
Patch1:         givaro-doc-no-build-time.patch
Patch2:         0001-Add-missing-include-cstdint-for-u-int64_t.patch
Patch3:         gcc14.patch
# Old doxygen does not properly handle symlink recursion
BuildRequires:  doxygen >= 1.5.7.1
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel >= 3.1.1
BuildRequires:  graphviz
BuildRequires:  libtool >= 2.2
BuildRequires:  pkg-config

%description
Givaro is a C++ library for arithmetic and algebraic computations.

%package -n %lname
Summary:        C++ library for arithmetic and algebraic computations
Group:          System/Libraries

%description -n %lname
Givaro is a C++ library for arithmetic and algebraic computations.

Its main features are implementations of the basic arithmetic of many
mathematical entities: Primes fields, Extensions Fields, Finite
Fields, Finite Rings, Polynomials, Algebraic numbers, Arbitrary
precision integers and rationals. It also provides data structures
and templated classes for the manipulation of basic algebraic
objects, such as vectors, matrices (dense, sparse, structured),
univariate polynomials (and therefore recursive multivariate).

It contains different program modules and is fully compatible with
the LinBox linear algebra library and the KAAPI kernel for
Adaptative, Asynchronous Parallel and Interactive programming.

%package devel
Summary:        Development files for Givaro, an algorithmic-algebraic computation library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Givaro is a C++ library for arithmetic and algebraic computations.

Its main features are implementations of the basic arithmetic of many
mathematical entities: Primes fields, Extensions Fields, Finite
Fields, Finite Rings, Polynomials, Algebraic numbers, Arbitrary
precision integers and rationals.

This subpackage contains the include files and library links for
developing against the Givaro library.

%package doc
Summary:        API documentation for the Givaro library, in HTML
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
Givaro is a C++ library for arithmetic and algebraic computations.

This subpackage contains the Doxygen-generated HTML documentation for
the Givaro API.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure --disable-static --enable-doc --with-docdir="%_docdir/%name" \
	--enable-silent-rules --disable-simd --without-archnative
chmod a+x givaro-config
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la
%fdupes -s %buildroot/%_docdir/%name/givaro-html/

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libgivaro.so.*
%license COPYRIGHT COPYING

%files devel
%_bindir/givaro-config
%_datadir/givaro/
%_includedir/givaro-config.h
%_includedir/givaro/
%_includedir/gmp++/
%_includedir/recint/
%_libdir/libgivaro.so
%_libdir/pkgconfig/givaro.pc

%files doc
%dir %_docdir/%name/
%exclude %_docdir/%name/givaro-html/INSTALL
%_docdir/%name/givaro.html
%_docdir/%name/givaro-html/

%changelog
* Mon Aug 19 2024 Jan Engelhardt <jengelh@inai.de>
- Add gcc14.patch
* Tue Mar 28 2023 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Add-missing-include-cstdint-for-u-int64_t.patch
* Tue Dec 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to 4.2.0
  * Change in the API for random iterators
  * New Modular ring over RecInt::rint elements
  * Fixed the max cardinalities for rings
- Drop reproducible.patch (merged)
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 4.1.1
  * Rewrote the Modular field code
* Fri Jul 13 2018 bwiedemann@suse.com
- Add reproducible.patch to disable compile-time CPU detection (boo#1100677)
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 4.0.4
  * build: fix SIMD detection script
- Drop 0001-pkgconfig-file-must-not-have-non-I-flags.patch
* Sat Sep  9 2017 jengelh@inai.de
- Add 0001-pkgconfig-file-must-not-have-non-I-flags.patch.
- Build with --disable-simd to get host-agnostic build results.
* Thu Oct 20 2016 jengelh@inai.de
- Update to new upstream release 4.0.2
  * No changelog was provided
- Remove new-abi.diff
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 4.0.1
  * This release is compatible with fflas-ffpack-2.2.0 and
  linbox-1.4.0.
  * Added a pkgconfig file for givaro
- Add new-abi.diff
* Sat Nov 14 2015 jengelh@inai.de
- Update to new upstream release 4.0.0
  * No upstream changelog was provided
* Sat Oct 11 2014 jengelh@inai.de
- Require a minimum doxygen version for proper symlink handling
  as used during givaro build.
- Move patch description to the patch.
* Sat Aug  9 2014 jengelh@inai.de
- Update to new upstream release 3.8.0
  * No upstream changelog was provided
* Thu May 23 2013 dmitry_r@opensuse.org
- Replace tarball by the original variant
- Replace duplicate files by links
- Delete timestamp from documentation
  * givaro-doc-no-build-time.patch
- Fix SLE11 build
* Sun May 19 2013 jengelh@inai.de
- Initial package (version 3.7.2) for build.opensuse.org
